==> react-lds-8.7.0.tgz: package/es/components/DataTable/DataTable.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es7.object.get-own-property-descriptors";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.array.from";
import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.object.set-prototype-of";
import "core-js/modules/es6.array.sort";
import "core-js/modules/es7.array.includes";
import "core-js/modules/es6.string.includes";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { keys.push.apply(keys, Object.getOwnPropertySymbols(object)); } if (enumerableOnly) keys = keys.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import isEmpty from 'lodash-es/isEmpty';
import omit from 'lodash-es/omit';
import { Row, Table } from '../Table';
import { uniqueId } from '../../utils';
import { propTypes as tablePropTypes } from '../Table/Table';
import defaultRowRenderer from './defaultRowRenderer';

var DataTable =
/*#__PURE__*/
function (_Component) {
  _inherits(DataTable, _Component);

  function DataTable(props) {
    var _this;

    _classCallCheck(this, DataTable);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DataTable).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "onSelect", function (rowId) {
      var _this$props = _this.props,
          onSelect = _this$props.onSelect,
          selection = _this$props.selection;

      if (onSelect) {
        var nextSelection = _toConsumableArray(selection);

        if (nextSelection.includes(rowId)) {
          nextSelection.splice(nextSelection.indexOf(rowId), 1);
        } else {
          nextSelection.push(rowId);
        }

        onSelect(nextSelection, rowId);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "onSelectAll", function () {
      var _this$props2 = _this.props,
          onSelect = _this$props2.onSelect,
          getRowId = _this$props2.getRowId;
      var data = _this.state.data;

      var allSelected = _this.areAllRowsSelected();

      var nextSelection = allSelected ? [] : data.map(function (rowData, rowIndex) {
        return getRowId({
          rowData: rowData,
          rowIndex: rowIndex
        });
      });

      if (onSelect) {
        onSelect(nextSelection);
      } // eslint-disable-next-line react/no-unused-state


      _this.setState({
        allSelected: !allSelected
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onSort", function () {
      var nextSortBy = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
      var onSort = _this.props.onSort;
      var _this$state = _this.state,
          data = _this$state.data,
          sortBy = _this$state.sortBy,
          sortDirection = _this$state.sortDirection;
      var nextSortDirection = 'asc'; // Same column as before => toggle sort order

      if (sortBy === nextSortBy) {
        nextSortDirection = sortDirection === 'asc' ? 'desc' : 'asc';
      }

      var nextState = {
        sortBy: nextSortBy,
        sortDirection: nextSortDirection
      };

      if (onSort) {
        onSort({
          dataKey: nextSortBy,
          sortDirection: nextSortDirection
        });

        _this.setState(nextState);
      } else {
        _this.setState(_objectSpread({}, nextState, {
          data: _toConsumableArray(data).sort(function (a, b) {
            return nextSortDirection === 'asc' ? String(a[nextSortBy]).localeCompare(b[nextSortBy]) : String(b[nextSortBy]).localeCompare(a[nextSortBy]);
          })
        }));
      }
    });

    var _this$props3 = _this.props,
        _data = _this$props3.data,
        _sortBy = _this$props3.sortBy,
        _sortDirection = _this$props3.sortDirection;
    _this.state = {
      id: uniqueId('data-table-advanced-'),
      columns: [],
      data: _data,
      sortBy: _sortBy,
      sortDirection: _sortDirection
    };
    return _this;
  }

  _createClass(DataTable, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      this.updateColumns();
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      var _this$props4 = this.props,
          children = _this$props4.children,
          data = _this$props4.data,
          sortBy = _this$props4.sortBy,
          sortDirection = _this$props4.sortDirection;

      if (nextProps.children !== children) {
        this.updateColumns();
      }

      if (nextProps.data !== data) {
        this.setState({
          data: nextProps.data
        });
      }

      if (nextProps.sortBy !== sortBy || nextProps.sortDirection !== sortDirection) {
        this.setState({
          sortBy: nextProps.sortBy,
          sortDirection: nextProps.sortDirection
        });
      }
    }
  }, {
    key: "updateColumns",
    // Loops over the `DataTableColumn` children and extracts their props as
    // config objects into `this.state.columns`.
    value: function updateColumns() {
      var children = this.props.children;

      if (children) {
        this.setState({
          columns: React.Children.toArray(children).filter(function (child) {
            return React.isValidElement(child);
          }).map(function (child) {
            return child.props;
          })
        });
      } else {
        this.setState({
          columns: []
        });
      }
    }
  }, {
    key: "areAllRowsSelected",
    value: function areAllRowsSelected() {
      var _this$props5 = this.props,
          getRowId = _this$props5.getRowId,
          selection = _this$props5.selection;
      var data = this.state.data;

      var allSelectedReducer = function allSelectedReducer(acc, rowData, rowIndex) {
        return acc && selection.includes(getRowId({
          rowIndex: rowIndex,
          rowData: rowData
        }));
      };

      return data.reduce(allSelectedReducer, true);
    }
  }, {
    key: "renderRow",
    value: function renderRow(rowData, rowIndex) {
      var _this2 = this;

      var _this$state2 = this.state,
          columns = _this$state2.columns,
          id = _this$state2.id;
      var _this$props6 = this.props,
          getCellData = _this$props6.getCellData,
          getRowId = _this$props6.getRowId,
          rowRenderer = _this$props6.rowRenderer,
          selection = _this$props6.selection,
          stickyHeader = _this$props6.stickyHeader;
      var rowId = getRowId({
        rowIndex: rowIndex,
        rowData: rowData
      });
      var cells = columns.map(function (_ref) {
        var cellRenderer = _ref.cellRenderer,
            dataKey = _ref.dataKey,
            title = _ref.title;
        return cellRenderer({
          cellData: getCellData({
            rowData: rowData,
            dataKey: dataKey
          }),
          dataKey: dataKey,
          onSelect: _this2.onSelect,
          rowData: rowData,
          rowId: rowId,
          rowIndex: rowIndex,
          selected: selection.includes(rowId),
          stickyHeader: stickyHeader,
          tableId: id,
          defaultProps: {
            'data-label': title,
            key: "".concat(rowId, "-").concat(dataKey),
            role: 'gridcell'
          }
        });
      });
      return rowRenderer({
        cells: cells,
        onSelect: this.onSelect,
        rowData: rowData,
        rowId: rowId,
        tableId: id
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var _this$props7 = this.props,
          className = _this$props7.className,
          noRowsRenderer = _this$props7.noRowsRenderer,
          stickyHeader = _this$props7.stickyHeader,
          variation = _this$props7.variation;
      var _this$state3 = this.state,
          columns = _this$state3.columns,
          data = _this$state3.data,
          id = _this$state3.id,
          sortBy = _this$state3.sortBy,
          sortDirection = _this$state3.sortDirection;
      var rest = omit(this.props, ['children', 'data', 'getCellData', 'getRowId', 'noRowsRenderer', 'onSelect', 'onSort', 'rowRenderer', 'selection', 'sortBy', 'sortDirection']);
      var hasHiddenHeader = !stickyHeader && variation.includes('header-hidden');
      var sldsClasses = [{
        'reactlds-table_stickyheader': stickyHeader
      }, className];
      return React.createElement(Table, _extends({}, rest, {
        className: cx(sldsClasses)
      }), React.createElement("thead", {
        className: hasHiddenHeader ? 'slds-assistive-text' : null
      }, React.createElement(Row, {
        sticky: stickyHeader
      }, columns.map(function (_ref2) {
        var headRenderer = _ref2.headRenderer,
            restProps = _objectWithoutProperties(_ref2, ["headRenderer"]);

        return headRenderer(_objectSpread({
          allSelected: _this3.areAllRowsSelected(),
          onSelectAll: _this3.onSelectAll,
          onSort: _this3.onSort,
          sortBy: sortBy,
          sortDirection: sortDirection,
          tableId: id
        }, restProps));
      }))), isEmpty(data) ? noRowsRenderer({
        columns: columns,
        tableId: id
      }) : React.createElement("tbody", null, data.map(function (row, i) {
        return _this3.renderRow(row, i);
      })));
    }
  }]);

  return DataTable;
}(Component);

DataTable.defaultProps = _objectSpread({}, Table.defaultProps, {
  getCellData: function getCellData(_ref3) {
    var rowData = _ref3.rowData,
        dataKey = _ref3.dataKey;
    return rowData[dataKey];
  },
  getRowId: function getRowId(_ref4) {
    var rowIndex = _ref4.rowIndex;
    return rowIndex;
  },
  onSort: null,
  onSelect: null,
  rowRenderer: defaultRowRenderer,
  noRowsRenderer: function noRowsRenderer() {},
  selection: [],
  sortBy: '',
  sortDirection: 'asc',
  stickyHeader: false
});
DataTable.propTypes = process.env.NODE_ENV !== "production" ? _objectSpread({}, tablePropTypes, {
  /**
   * Table content, an array of objects
   */
  data: PropTypes.arrayOf(PropTypes.any).isRequired,

  /**
   * Getter which returns a unique id for a row. The default implementation will
   * just use the row index. Overwrite this with a better id if you plan on
   * using a variable `data` array.
   */
  getRowId: PropTypes.func,

  /**
   * Getter which returns the value for a single cell. Receives the current row
   * and the column's data key.
   */
  getCellData: PropTypes.func,

  /**
   * Render callback which is called if the data array is empty. Should return a
   * table body.
   */
  noRowsRenderer: PropTypes.func,

  /**
   * Callback, triggered by clicks on sortable column headers.  Receives an object
   * which contains the `dataKey` of the column to sort by and the `sortDirection`
   * (`asc` or `desc`). If omitted, the rows will be sorted by a `String.localeCompare`.
   */
  onSort: PropTypes.func,

  /**
   * Callback, triggered whenever one or more rows have been selected. Returns
   * an array containing all selected row IDs.
   */
  onSelect: PropTypes.func,

  /**
   * Callback used for rendering rows. See `defaultRowRenderer` for a sample.
   */
  rowRenderer: PropTypes.func,

  /**
   * Array of indexes of selected rows.
   */
  selection: PropTypes.array,

  /**
   * Initial sort column, identified by `dataKey`.
   */
  sortBy: PropTypes.string,

  /**
   * Initial sort direction (`asc` or `desc`).
   */
  sortDirection: PropTypes.string,

  /**
   * Make table header stick to the top
   */
  stickyHeader: PropTypes.bool
}) : {};
export default DataTable;

==> react-lds-9.1.0.tgz: package/es/components/DataTable/DataTable.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.from";
import "core-js/modules/es.array.includes";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.array.map";
import "core-js/modules/es.array.reduce";
import "core-js/modules/es.array.sort";
import "core-js/modules/es.array.splice";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.includes";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.for-each";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import isEmpty from 'lodash-es/isEmpty';
import omit from 'lodash-es/omit';
import { Row, Table } from '../Table';
import { uniqueId } from '../../utils';
import { propTypes as tablePropTypes } from '../Table/Table';
import defaultRowRenderer from './defaultRowRenderer';

var DataTable =
/*#__PURE__*/
function (_Component) {
  _inherits(DataTable, _Component);

  function DataTable(props) {
    var _this;

    _classCallCheck(this, DataTable);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DataTable).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "onSelect", function (rowId) {
      var _this$props = _this.props,
          onSelect = _this$props.onSelect,
          selection = _this$props.selection;

      if (onSelect) {
        var nextSelection = _toConsumableArray(selection);

        if (nextSelection.includes(rowId)) {
          nextSelection.splice(nextSelection.indexOf(rowId), 1);
        } else {
          nextSelection.push(rowId);
        }

        onSelect(nextSelection, rowId);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "onSelectAll", function () {
      var _this$props2 = _this.props,
          onSelect = _this$props2.onSelect,
          getRowId = _this$props2.getRowId;
      var data = _this.state.data;

      var allSelected = _this.areAllRowsSelected();

      var nextSelection = allSelected ? [] : data.map(function (rowData, rowIndex) {
        return getRowId({
          rowData: rowData,
          rowIndex: rowIndex
        });
      });

      if (onSelect) {
        onSelect(nextSelection);
      } // eslint-disable-next-line react/no-unused-state


      _this.setState({
        allSelected: !allSelected
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onSort", function () {
      var nextSortBy = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
      var onSort = _this.props.onSort;
      var _this$state = _this.state,
          data = _this$state.data,
          sortBy = _this$state.sortBy,
          sortDirection = _this$state.sortDirection;
      var nextSortDirection = 'asc'; // Same column as before => toggle sort order

      if (sortBy === nextSortBy) {
        nextSortDirection = sortDirection === 'asc' ? 'desc' : 'asc';
      }

      var nextState = {
        sortBy: nextSortBy,
        sortDirection: nextSortDirection
      };

      if (onSort) {
        onSort({
          dataKey: nextSortBy,
          sortDirection: nextSortDirection
        });

        _this.setState(nextState);
      } else {
        _this.setState(_objectSpread({}, nextState, {
          data: _toConsumableArray(data).sort(function (a, b) {
            return nextSortDirection === 'asc' ? String(a[nextSortBy]).localeCompare(b[nextSortBy]) : String(b[nextSortBy]).localeCompare(a[nextSortBy]);
          })
        }));
      }
    });

    var _this$props3 = _this.props,
        _data = _this$props3.data,
        _sortBy = _this$props3.sortBy,
        _sortDirection = _this$props3.sortDirection;
    _this.state = {
      id: uniqueId('data-table-advanced-'),
      columns: [],
      data: _data,
      sortBy: _sortBy,
      sortDirection: _sortDirection
    };
    return _this;
  }

  _createClass(DataTable, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      this.updateColumns();
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      var _this$props4 = this.props,
          children = _this$props4.children,
          data = _this$props4.data,
          sortBy = _this$props4.sortBy,
          sortDirection = _this$props4.sortDirection;

      if (nextProps.children !== children) {
        this.updateColumns();
      }

      if (nextProps.data !== data) {
        this.setState({
          data: nextProps.data
        });
      }

      if (nextProps.sortBy !== sortBy || nextProps.sortDirection !== sortDirection) {
        this.setState({
          sortBy: nextProps.sortBy,
          sortDirection: nextProps.sortDirection
        });
      }
    }
  }, {
    key: "updateColumns",
    // Loops over the `DataTableColumn` children and extracts their props as
    // config objects into `this.state.columns`.
    value: function updateColumns() {
      var children = this.props.children;

      if (children) {
        this.setState({
          columns: React.Children.toArray(children).filter(function (child) {
            return React.isValidElement(child);
          }).map(function (child) {
            return child.props;
          })
        });
      } else {
        this.setState({
          columns: []
        });
      }
    }
  }, {
    key: "areAllRowsSelected",
    value: function areAllRowsSelected() {
      var _this$props5 = this.props,
          getRowId = _this$props5.getRowId,
          selection = _this$props5.selection;
      var data = this.state.data;

      var allSelectedReducer = function allSelectedReducer(acc, rowData, rowIndex) {
        return acc && selection.includes(getRowId({
          rowIndex: rowIndex,
          rowData: rowData
        }));
      };

      return data.reduce(allSelectedReducer, true);
    }
  }, {
    key: "renderRow",
    value: function renderRow(rowData, rowIndex) {
      var _this2 = this;

      var _this$state2 = this.state,
          columns = _this$state2.columns,
          id = _this$state2.id;
      var _this$props6 = this.props,
          getCellData = _this$props6.getCellData,
          getRowId = _this$props6.getRowId,
          rowRenderer = _this$props6.rowRenderer,
          selection = _this$props6.selection,
          stickyHeader = _this$props6.stickyHeader;
      var rowId = getRowId({
        rowIndex: rowIndex,
        rowData: rowData
      });
      var cells = columns.map(function (_ref) {
        var cellRenderer = _ref.cellRenderer,
            dataKey = _ref.dataKey,
            title = _ref.title;
        return cellRenderer({
          cellData: getCellData({
            rowData: rowData,
            dataKey: dataKey
          }),
          dataKey: dataKey,
          onSelect: _this2.onSelect,
          rowData: rowData,
          rowId: rowId,
          rowIndex: rowIndex,
          selected: selection.includes(rowId),
          stickyHeader: stickyHeader,
          tableId: id,
          defaultProps: {
            'data-label': title,
            key: "".concat(rowId, "-").concat(dataKey),
            role: 'gridcell'
          }
        });
      });
      return rowRenderer({
        cells: cells,
        onSelect: this.onSelect,
        rowData: rowData,
        rowId: rowId,
        tableId: id
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var _this$props7 = this.props,
          className = _this$props7.className,
          noRowsRenderer = _this$props7.noRowsRenderer,
          stickyHeader = _this$props7.stickyHeader,
          variation = _this$props7.variation;
      var _this$state3 = this.state,
          columns = _this$state3.columns,
          data = _this$state3.data,
          id = _this$state3.id,
          sortBy = _this$state3.sortBy,
          sortDirection = _this$state3.sortDirection;
      var rest = omit(this.props, ['children', 'data', 'getCellData', 'getRowId', 'noRowsRenderer', 'onSelect', 'onSort', 'rowRenderer', 'selection', 'sortBy', 'sortDirection']);
      var hasHiddenHeader = !stickyHeader && variation.includes('header-hidden');
      var sldsClasses = [{
        'reactlds-table_stickyheader': stickyHeader
      }, className];
      return React.createElement(Table, _extends({}, rest, {
        className: cx(sldsClasses)
      }), React.createElement("thead", {
        className: hasHiddenHeader ? 'slds-assistive-text' : null
      }, React.createElement(Row, {
        sticky: stickyHeader
      }, columns.map(function (_ref2) {
        var headRenderer = _ref2.headRenderer,
            restProps = _objectWithoutProperties(_ref2, ["headRenderer"]);

        return headRenderer(_objectSpread({
          allSelected: _this3.areAllRowsSelected(),
          onSelectAll: _this3.onSelectAll,
          onSort: _this3.onSort,
          sortBy: sortBy,
          sortDirection: sortDirection,
          tableId: id
        }, restProps));
      }))), isEmpty(data) ? noRowsRenderer({
        columns: columns,
        tableId: id
      }) : React.createElement("tbody", null, data.map(function (row, i) {
        return _this3.renderRow(row, i);
      })));
    }
  }]);

  return DataTable;
}(Component);

DataTable.defaultProps = _objectSpread({}, Table.defaultProps, {
  getCellData: function getCellData(_ref3) {
    var rowData = _ref3.rowData,
        dataKey = _ref3.dataKey;
    return rowData[dataKey];
  },
  getRowId: function getRowId(_ref4) {
    var rowIndex = _ref4.rowIndex;
    return rowIndex;
  },
  onSort: null,
  onSelect: null,
  rowRenderer: defaultRowRenderer,
  noRowsRenderer: function noRowsRenderer() {},
  selection: [],
  sortBy: '',
  sortDirection: 'asc',
  stickyHeader: false
});
DataTable.propTypes = process.env.NODE_ENV !== "production" ? _objectSpread({}, tablePropTypes, {
  /**
   * Table content, an array of objects
   */
  data: PropTypes.arrayOf(PropTypes.any).isRequired,

  /**
   * Getter which returns a unique id for a row. The default implementation will
   * just use the row index. Overwrite this with a better id if you plan on
   * using a variable `data` array.
   */
  getRowId: PropTypes.func,

  /**
   * Getter which returns the value for a single cell. Receives the current row
   * and the column's data key.
   */
  getCellData: PropTypes.func,

  /**
   * Render callback which is called if the data array is empty. Should return a
   * table body.
   */
  noRowsRenderer: PropTypes.func,

  /**
   * Callback, triggered by clicks on sortable column headers.  Receives an object
   * which contains the `dataKey` of the column to sort by and the `sortDirection`
   * (`asc` or `desc`). If omitted, the rows will be sorted by a `String.localeCompare`.
   */
  onSort: PropTypes.func,

  /**
   * Callback, triggered whenever one or more rows have been selected. Returns
   * an array containing all selected row IDs.
   */
  onSelect: PropTypes.func,

  /**
   * Callback used for rendering rows. See `defaultRowRenderer` for a sample.
   */
  rowRenderer: PropTypes.func,

  /**
   * Array of indexes of selected rows.
   */
  selection: PropTypes.array,

  /**
   * Initial sort column, identified by `dataKey`.
   */
  sortBy: PropTypes.string,

  /**
   * Initial sort direction (`asc` or `desc`).
   */
  sortDirection: PropTypes.string,

  /**
   * Make table header stick to the top
   */
  stickyHeader: PropTypes.bool
}) : {};
export default DataTable;
